elephant.spike\_train\_generation.StationaryPoissonProcess
==========================================================

.. currentmodule:: elephant.spike_train_generation

.. autoclass:: StationaryPoissonProcess
   :members:
   :inherited-members:
   :special-members: __call__, __getitem__, __setitem__

   

   
   .. rubric:: Methods

   .. autosummary::
   
      ~StationaryPoissonProcess.__init__
      ~StationaryPoissonProcess.generate_n_spiketrains
      ~StationaryPoissonProcess.generate_spiketrain
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~StationaryPoissonProcess.expected_cv
      ~StationaryPoissonProcess.t_start
      ~StationaryPoissonProcess.t_stop
      ~StationaryPoissonProcess.isi_generator
   
   